/*
 *
 * Copyright  2005, University of Washington, 
 * Department of Computer Science and Engineering. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 *
 * 3. Neither name of the University of Washington, Department of Computer 
 * Science and Engineering nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR 
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *
 */

#pragma once

#include "FTDI466API.h"

namespace ColorSelectorCpp
{
using namespace System;

public __gc class SerialCtrl
{	

public:

	// SerialCtrl::SerialCtrl()
	// Default Constructor
	SerialCtrl();

	// SerialCtrl::SerialCtrl()
	// Default Deconstructor
	~SerialCtrl();

	// SerialCtrl::SPIInitialize()
	// Initializes the device.
	// Returns true on success, false on failure.
	bool SPIInitialize();

	// SerialCtrl::SPIUninitialize()
	// Closes the device
	void SPIUninitialize();

	// SerialCtrl::SPITransaction()
	// Creates a data transaction with the specified device.
	// Sends the data in value to the device specified by newDevice.  Data received from the device
	// is stored in rxBuffer, and the number
	// of bytes received is reported in the numBytesReceived variable.
	// Returns true on successful transaction, and false on failure
	bool SPITransaction(unsigned char* txBuffer, unsigned char* rxBuffer, DWORD* numBytesReceived, DWORD* numBytesToSend);

	// SerialCtrl::DecodeInput
	// Decode the input received from the USB device
	void DecodeInput(unsigned char* rxBuffer, int* xSpeed, int* ySpeed, int* leftButtonPressed, int* rightButtonPressed);

private:

	FTDI466API* device;

};

}
